Simple tests
-------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/simpleio_tone_demo.py
    :caption: examples/simpleio_tone_demo.py
    :linenos:

.. literalinclude:: ../examples/simpleio_shift_in_out_demo.py
    :caption: examples/simpleio_shift_in_out_demo.py
    :linenos:

.. literalinclude:: ../examples/simpleio_map_range_simpletest.py
    :caption: examples/simpleio_map_range_simpletest.py
    :linenos:
